Script Reference
================

.. _checkGenuine.py:

checkGenuine.py
---------------

.. argparse::
   :module: ledgerblue.checkGenuine
   :func: get_argparser
   :prog: python -m ledgerblue.checkGenuine

.. _deleteApp.py:

deleteApp.py
------------

.. argparse::
   :module: ledgerblue.deleteApp
   :func: get_argparser
   :prog: python -m ledgerblue.deleteApp

.. _derivePassphrase.py:

derivePassphrase.py
-------------------

.. argparse::
   :module: ledgerblue.derivePassphrase
   :func: get_argparser
   :prog: python -m ledgerblue.derivePassphrase

.. _endorsementSetupLedger.py:

endorsementSetupLedger.py
-------------------------

.. argparse::
   :module: ledgerblue.endorsementSetupLedger
   :func: get_argparser
   :prog: python -m ledgerblue.endorsementSetupLedger

.. _endorsementSetup.py:

endorsementSetup.py
-------------------

.. argparse::
   :module: ledgerblue.endorsementSetup
   :func: get_argparser
   :prog: python -m ledgerblue.endorsementSetup

.. _genCAPair.py:

genCAPair.py
------------

.. argparse::
   :module: ledgerblue.genCAPair
   :func: get_argparser
   :prog: python -m ledgerblue.genCAPair

.. _hashApp.py:

hashApp.py
----------

.. argparse::
   :module: ledgerblue.hashApp
   :func: get_argparser
   :prog: python -m ledgerblue.hashApp

.. _hostOnboard.py:

hostOnboard.py
--------------

.. argparse::
   :module: ledgerblue.hostOnboard
   :func: get_argparser
   :prog: python -m ledgerblue.hostOnboard

.. _listApps.py:

listApps.py
-----------

.. argparse::
   :module: ledgerblue.listApps
   :func: get_argparser
   :prog: python -m ledgerblue.listApps

.. _loadApp.py:

loadApp.py
----------

.. argparse::
   :module: ledgerblue.loadApp
   :func: get_argparser
   :prog: python -m ledgerblue.loadApp

.. _loadMCU.py:

loadMCU.py
----------

.. argparse::
   :module: ledgerblue.loadMCU
   :func: get_argparser
   :prog: python -m ledgerblue.loadMCU

.. _mcuBootloader.py:

mcuBootloader.py
----------------

.. argparse::
   :module: ledgerblue.mcuBootloader
   :func: get_argparser
   :prog: python -m ledgerblue.mcuBootloader

.. _resetCustomCA.py:

resetCustomCA.py
----------------

.. argparse::
   :module: ledgerblue.resetCustomCA
   :func: get_argparser
   :prog: python -m ledgerblue.resetCustomCA

.. _runApp.py:

runApp.py
---------

.. argparse::
   :module: ledgerblue.runApp
   :func: get_argparser
   :prog: python -m ledgerblue.runApp

.. _runScript.py:

runScript.py
------------

.. argparse::
   :module: ledgerblue.runScript
   :func: get_argparser
   :prog: python -m ledgerblue.runScript

.. _setupCustomCA.py:

setupCustomCA.py
----------------

.. argparse::
   :module: ledgerblue.setupCustomCA
   :func: get_argparser
   :prog: python -m ledgerblue.setupCustomCA

.. _signApp.py:

signApp.py
----------

See :ref:`loadApp <loadApp.py>`, and its `--signApp` flag.

.. _updateFirmware.py:

updateFirmware.py
-----------------

.. argparse::
   :module: ledgerblue.updateFirmware
   :func: get_argparser
   :prog: python -m ledgerblue.updateFirmware

.. _verifyApp.py:

verifyApp.py
------------

.. argparse::
   :module: ledgerblue.verifyApp
   :func: get_argparser
   :prog: python -m ledgerblue.verifyApp

.. _verifyEndorsement1.py:

verifyEndorsement1.py
---------------------

.. argparse::
   :module: ledgerblue.verifyEndorsement1
   :func: get_argparser
   :prog: python -m ledgerblue.verifyEndorsement1

.. _verifyEndorsement2.py:

verifyEndorsement2.py
---------------------

.. argparse::
   :module: ledgerblue.verifyEndorsement2
   :func: get_argparser
   :prog: python -m ledgerblue.verifyEndorsement2
